"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = require("path");
var shortid_1 = require("shortid");
function generateSandboxFile(module, path, parentDirectoryShortid) {
    return {
        shortid: shortid_1.generate(),
        code: module.content,
        directoryShortid: parentDirectoryShortid,
        title: path_1.basename(path),
        isBinary: module.isBinary,
    };
}
function createDirectoryRecursively(path, directories) {
    if (directories[path]) {
        return directories[path];
    }
    var parentDir = path_1.dirname(path);
    // This means root, so create it
    if (parentDir === '.') {
        directories[path] = generateSandboxDirectory(path, undefined);
        return;
    }
    if (!directories[parentDir]) {
        createDirectoryRecursively(parentDir, directories);
    }
    directories[path] = generateSandboxDirectory(path_1.basename(path), directories[parentDir].shortid);
}
function generateSandboxDirectory(title, parentDirectoryShortid) {
    return {
        shortid: shortid_1.generate(),
        directoryShortid: parentDirectoryShortid,
        title: title,
    };
}
function denormalize(files) {
    var directories = new Set();
    Object.keys(files).forEach(function (path) {
        var dir = path_1.dirname(path);
        if (dir !== '.') {
            directories.add(path_1.dirname(path));
        }
    });
    var sandboxDirectories = {};
    Array.from(directories).forEach(function (dirPath) {
        createDirectoryRecursively(dirPath, sandboxDirectories);
    });
    var sandboxModules = Object.keys(files).map(function (path) {
        var dir = sandboxDirectories[path_1.dirname(path)];
        var parentShortid = dir ? dir.shortid : undefined;
        return generateSandboxFile(files[path], path, parentShortid);
    });
    return {
        modules: sandboxModules,
        directories: Object.keys(sandboxDirectories).map(function (s) { return sandboxDirectories[s]; }),
    };
}
exports.default = denormalize;
//# sourceMappingURL=denormalize.js.map